@@ -2,11 +2,13 @@
 
 use crate::colors;
 use crate::graph::Dependency;
+use crate::graph::EsModule;
 use crate::graph::Module;
 use crate::graph::ModuleGraph;
 use crate::graph::ModuleGraphError;
 use crate::graph::ModuleSlot;
 use crate::graph::Resolved;
+use crate::graph::SyntheticModule;
 use crate::module_specifier::ModuleSpecifier;
 
 use std::collections::HashSet;
@@ -53,7 +55,7 @@ impl fmt::Display for ModuleGraph {
     let root_specifier = self.resolve(&self.roots[0]);
     match self.module_slots.get(&root_specifier) {
       Some(ModuleSlot::Module(root)) => {
-        if let Some(cache_info) = &root.maybe_cache_info {
+        if let Some(cache_info) = root.maybe_cache_info() {
           if let Some(local) = &cache_info.local {
             writeln!(
               f,
@@ -74,16 +76,13 @@ impl fmt::Display for ModuleGraph {
             writeln!(f, "{} {}", colors::bold("map:"), map.to_string_lossy())?;
           }
         }
-        writeln!(f, "{} {}", colors::bold("type:"), root.media_type)?;
+        writeln!(f, "{} {}", colors::bold("type:"), root.media_type())?;
         let total_size: f64 = self
           .module_slots
           .iter()
-          .filter_map(|(_, m)| {
-            if let ModuleSlot::Module(module) = m {
-              Some(module.size() as f64)
-            } else {
-              None
-            }
+          .filter_map(|(_, m)| match m {
+            ModuleSlot::Module(module) => Some(module.size() as f64),
+            _ => None,
           })
           .sum();
         let dep_count = self
@@ -106,15 +105,17 @@ impl fmt::Display for ModuleGraph {
           colors::gray(format!("({})", human_size(root.size() as f64)))
         )?;
         let mut seen = HashSet::new();
-        let dep_len = root.dependencies.len();
-        for (idx, (_, dep)) in root.dependencies.iter().enumerate() {
-          dep.fmt_info(
-            f,
-            "",
-            idx == dep_len - 1 && root.maybe_types_dependency.is_none(),
-            self,
-            &mut seen,
-          )?;
+        if let Some(dependencies) = root.maybe_dependencies() {
+          let dep_len = dependencies.len();
+          for (idx, (_, dep)) in dependencies.iter().enumerate() {
+            dep.fmt_info(
+              f,
+              "",
+              idx == dep_len - 1 && root.maybe_types_dependency().is_none(),
+              self,
+              &mut seen,
+            )?;
+          }
         }
         Ok(())
       }
@@ -159,6 +160,55 @@ impl Dependency {
 }
 
 impl Module {
+  fn fmt_info<S: AsRef<str> + fmt::Display + Clone>(
+    &self,
+    f: &mut fmt::Formatter,
+    prefix: S,
+    last: bool,
+    graph: &ModuleGraph,
+    type_dep: bool,
+    seen: &mut HashSet<ModuleSpecifier>,
+  ) -> fmt::Result {
+    match self {
+      Self::Es(m) => m.fmt_info(f, prefix, last, graph, type_dep, seen),
+      Self::Synthetic(m) => m.fmt_info(f, prefix, last, seen),
+    }
+  }
+}
+
+impl SyntheticModule {
+  fn fmt_info<S: AsRef<str> + fmt::Display + Clone>(
+    &self,
+    f: &mut fmt::Formatter,
+    prefix: S,
+    last: bool,
+    seen: &mut HashSet<ModuleSpecifier>,
+  ) -> fmt::Result {
+    let was_seen = seen.contains(&self.specifier);
+    let (specifier_str, size_str) = if was_seen {
+      let specifier_str = colors::gray(&self.specifier).to_string();
+      (specifier_str, colors::gray(" *").to_string())
+    } else {
+      let specifier_str = self.specifier.to_string();
+      let size_str =
+        colors::gray(format!(" ({})", human_size(self.size() as f64)))
+          .to_string();
+      (specifier_str, size_str)
+    };
+
+    seen.insert(self.specifier.clone());
+
+    fmt_info_msg(
+      f,
+      prefix,
+      last,
+      false,
+      format!("{}{}", specifier_str, size_str),
+    )
+  }
+}
+
+impl EsModule {
   fn fmt_info<S: AsRef<str> + fmt::Display + Clone>(
     &self,
     f: &mut fmt::Formatter,
@@ -533,6 +583,77 @@ https://deno.land/x/example/a.ts (129B)
 ├── https://deno.land/x/example/f.d.ts (22B)
 └─┬ https://deno.land/x/example/g.js (21B)
   └── https://deno.land/x/example/g.d.ts (20B)
+"#
+    );
+  }
+
+  #[tokio::test]
+  async fn test_info_graph_import_assertion() {
+    let mut loader = MemoryLoader::new(
+      vec![
+        (
+          "https://deno.land/x/example/a.ts",
+          Ok((
+            "https://deno.land/x/example/a.ts",
+            Some(vec![("content-type", "application/typescript")]),
+            r#"import b from "./b.json" assert { type: "json" };
+            const c = await import("./c.json", { assert: { type: "json" } });
+            "#,
+          )),
+        ),
+        (
+          "https://deno.land/x/example/b.json",
+          Ok((
+            "https://deno.land/x/example/b.json",
+            Some(vec![("content-type", "application/json")]),
+            r#"{"b":"c"}"#,
+          )),
+        ),
+        (
+          "https://deno.land/x/example/c.json",
+          Ok((
+            "https://deno.land/x/example/c.json",
+            Some(vec![("content-type", "application/json")]),
+            r#"{"c":1}"#,
+          )),
+        ),
+      ],
+      vec![(
+        "https://deno.land/x/example/a.ts",
+        CacheInfo {
+          local: Some(PathBuf::from(
+            "/cache/deps/https/deno.land/x/example/a.ts",
+          )),
+          emit: Some(PathBuf::from(
+            "/cache/deps/https/deno.land/x/example/a.js",
+          )),
+          ..Default::default()
+        },
+      )],
+    );
+    let root_specifier =
+      ModuleSpecifier::parse("https://deno.land/x/example/a.ts").unwrap();
+    let source_parser = DefaultSourceParser::new();
+    let builder = Builder::new(
+      vec![root_specifier],
+      false,
+      &mut loader,
+      None,
+      None,
+      &source_parser,
+    );
+    let graph = builder.build(None).await;
+    println!("{}", graph);
+    assert_eq!(
+      strip_ansi_codes(format!("{}", graph)),
+      r#"local: /cache/deps/https/deno.land/x/example/a.ts
+emit: /cache/deps/https/deno.land/x/example/a.js
+type: TypeScript
+dependencies: 2 unique (total 156B)
+
+https://deno.land/x/example/a.ts (140B)
+├── https://deno.land/x/example/b.json (9B)
+└── https://deno.land/x/example/c.json (7B)
 "#
     );
   }
